@@ -842,6 +842,7 @@ WorksheetEntry* Worksheet::insertEntry(const int type, WorksheetEntry* current)
 
     focusEntry(entry);
     makeVisible(entry);
+
     return entry;
 }
 
@@ -862,7 +863,10 @@ WorksheetEntry* Worksheet::insertCommandEntry(WorksheetEntry* current)
 
 WorksheetEntry* Worksheet::insertImageEntry(WorksheetEntry* current)
 {
-    return insertEntry(ImageEntry::Type, current);
+    auto* entry = insertEntry(ImageEntry::Type, current);
+    auto* imageEntry = static_cast<ImageEntry*>(entry);
+    QTimer::singleShot(0, this, [=] () {imageEntry->startConfigDialog();});
+    return entry;
 }
 
 WorksheetEntry* Worksheet::insertPageBreakEntry(WorksheetEntry* current)
@@ -940,7 +944,10 @@ WorksheetEntry* Worksheet::insertPageBreakEntryBefore(WorksheetEntry* current)
 
 WorksheetEntry* Worksheet::insertImageEntryBefore(WorksheetEntry* current)
 {
-    return insertEntryBefore(ImageEntry::Type, current);
+    auto* entry = insertEntryBefore(ImageEntry::Type, current);
+    auto* imageEntry = static_cast<ImageEntry*>(entry);
+    QTimer::singleShot(0, this, [=] () {imageEntry->startConfigDialog();});
+    return entry;
 }
 
 WorksheetEntry* Worksheet::insertLatexEntryBefore(WorksheetEntry* current)
